@@ -22,13 +22,13 @@ kmtype.original <- "original"
 kmtype.main <- "main"
 kmtype.versions <- "versions"
 kmtype.metaversions <- "metaversions"
+kmtype.corecitation <- "corecitation"
+kmtype.corpuscitation <- "corpuscitation"
 
-kcitation <- "Lehmann, Pola / Merz, Nicolas / Regel, Sven / Werner, Annika (2015): Manifesto Corpus. Berlin: WZB Berlin Social Science Center."
 kcitemessage <- paste0("When publishing work using the Manifesto Corpus, please ",
-                       "make sure to give the identification number of the corpus version ",
-                       "used for your analysis and to reference\n\n",
-                       kcitation)
+                       "make sure to cite it correctly and to give the identification ",
+                       "number of the corpus version used for your analysis.")
 
-message(paste0(kcitemessage, "\n\n",
-               "You can print citation and version information with ",
-               "the function mp_cite()."))
+message(paste(kcitemessage,
+  "You can print citation and version information with the function mp_cite().",
+  sep = "\n\n"))
